@@ -1,8 +1,8 @@
 """Tests for the flatten observation wrapper."""
 from flask import Flask, request
 import json
-import globalvar as gl
-import log
+import ai_hub.globalvar as gl
+import ai_hub.log
 
 app = Flask("tccapi")
 
