@@ -1,12 +1,12 @@
 from inferServer import inferServer
-import globalvar as gl
+#import ai_hub.globalvar as gl
 import json
-import log
+import ai_hub.log
 
 class myserver(inferServer):
     def __init__(self,model):
         super().__init__(model)
-        print("init_myserver")
+        log.i("init_myserver")
 
     def pre_process(self, data):
         log.i("my_pre_process.")
